QueryBuilder

Struct QueryBuilder 

pub struct QueryBuilder<'a, T: Columned> { /* private fields */ }
Builder used to easily construct simple SELECT, UPDATE and DELETE queries.

Implementations

Source

impl<'a, T: Columned> QueryBuilder<'a, T>

pub fn new() -> QueryBuilder<'a, T>

Create a new QueryBuilder.

pub fn set(self, key: T::WriteKeys, val: &'a (dyn ToSql + Sync)) -> Self

Set a column to a value for an upcoming update_one or update_many call.

pub fn where_eq(self, key: T::ReadKeys, val: &'a (dyn ToSql + Sync)) -> Self

Filter results where the provided column equals the value.

pub fn where_ne(self, key: T::ReadKeys, val: &'a (dyn ToSql + Sync)) -> Self

Filter results where the provided column does not equal the value.

pub fn and(self) -> Self

Append an AND to the where clause.

pub fn or(self) -> Self

Append an OR to the where clause.

pub fn limit(self, val: i32) -> Self

Apply a limit

pub fn offset(self, val: i32) -> Self

Apply an offset

pub fn force(self) -> Self

By default, write operations without a “WHERE” clause will be rejected. Call this function to force it to work.

pub async fn get( self, db: &DatabaseConnection, ) -> Result<Option<T>, PostgresReadError>

Select one will fetch an object from the database, and return an Option indicating whether it’s been found.

pub async fn select_all( self, db: &DatabaseConnection, ) -> Result<Vec<T>, PostgresReadError>

Select all will fetch many objects from the database, and return a Vec. If no options are found, an empty Vec is returned.

pub async fn update_many( self, db: &DatabaseConnection, ) -> Result<Vec<T>, PostgresWriteError>

Update rows and return all updated records.

pub async fn update_one( self, db: &DatabaseConnection, ) -> Result<Option<T>, PostgresWriteError>

Update row and return first updated record.

pub async fn delete( &self, db: &DatabaseConnection, ) -> Result<(), PostgresWriteError>

Delete rows matching the provided condition.