PostgresBulkWriteable

Trait PostgresBulkWriteable 

pub trait PostgresBulkWriteable {
    // Required method
    fn into_bulk_write(self) -> PostgresWrite;
}
A trait for defining a struct as bulk writeable. This is typically defined on collections of structs. Tusk includes a default implementation for Vec where T implements PostgresWriteable.

Required Methods

Implementations on Foreign Types

Source

impl<T: PostgresWriteable + PostgresTable> PostgresBulkWriteable for Vec<T>

Implementors