pub trait PostgresWriteFields {
// Required method
fn write_fields() -> &'static [&'static str];
}Expand description
A trait for defining fields to write to in Postgres. This is required for all Tusk database operations.
Unlike PostgresReadFields, this trait
returns static string slices instead of structs.
Because the struct data is not needed to perform writes,
this improves performance.
Required Methods
fn write_fields() -> &'static [&'static str]
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.